@@ -307,16 +307,14 @@ class LevelView(QWidget):
 
     @undoable
     def _change_object_on_mouse_wheel(self, cursor_position: QPoint, y_delta: int):
-        x, y = cursor_position.toTuple()
+        x, y = cursor_position.x(), cursor_position.y()
 
-        obj_under_cursor = self.object_at(x, y)
+        obj = self.object_at(x, y)
 
-        if y_delta > 0:
-            obj_under_cursor.increment_type()
-        else:
-            obj_under_cursor.decrement_type()
-
-        obj_under_cursor.selected = True
+        if obj is None:
+            return
+        obj.increment_type() if y_delta > 0 else obj.decrement_type()
+        obj.selected = True
 
     def sizeHint(self) -> QSize:
         if not self.level_ref:
@@ -407,18 +405,14 @@ class LevelView(QWidget):
         self.mouse_mode = MODE_FREE
         self.setCursor(Qt.ArrowCursor)
 
-    def _stop_resize(self, _):
-        if self.resizing_happened:
-            self.level_ref.save_level_state()
-
+    def _stop_resize(self):
+        self.level_ref.save_level_state()
         self.resizing_happened = False
         self.mouse_mode = MODE_FREE
         self.setCursor(Qt.ArrowCursor)
 
     def _on_left_mouse_button_down(self, event: QMouseEvent):
-        if self.resizing_happened:
-            self._on_resize_happened_mouse_up(event)
-        elif self._select_objects_on_click(event):
+        if self._select_objects_on_click(event):
             x, y = event.position().toPoint().toTuple()
 
             obj = self.object_at(x, y)
@@ -439,7 +433,7 @@ class LevelView(QWidget):
 
         resize_end_x, _ = self._to_level_point(x, y)
         if self.resize_mouse_start_x != resize_end_x:
-            self._stop_resize(event)
+            self._stop_resize()
 
     @staticmethod
     def _resize_mode_from_edge(edge: int):
@@ -475,7 +469,9 @@ class LevelView(QWidget):
         self.update()
 
     def _on_left_mouse_button_up(self, event: QMouseEvent):
-        if self.mouse_mode == MODE_DRAG and self.dragging_happened:
+        if self.resizing_happened:
+            self._on_resize_happened_mouse_up(event)
+        elif self.mouse_mode == MODE_DRAG and self.dragging_happened:
             x, y = event.position().toPoint().toTuple()
 
             obj = self.object_at(x, y)
